@@ -341,18 +341,25 @@ class JsonResource(Resource):
         return json.dumps(self.data, indent=2, ensure_ascii=False)
 
 
+    def jsonpath_exists(self, json_path:str) -> bool:
+        """
+        Checks if a jsonpath exists
+        """
+        try:
+            self.get_jsonpath(json_path)
+            return True
+        except AssetNotFoundError:
+            return False
+
     def delete_jsonpath(self, json_path:str, ensure_exists:bool = False) -> None:
         """
         Removes value at jsonpath location.
         """
-        try:
+        path_exists = self.jsonpath_exists
+        if path_exists:
             dpath.util.delete(self.data, json_path)
-        except dpath.exceptions.PathNotFound as path_not_found:
-            if ensure_exists:
-                raise dpath.exceptions.PathNotFound(
-                    f"Path {json_path} does not exist."
-                ) from path_not_found
-
+        elif ensure_exists:
+            raise AssetNotFoundError(f"Path {json_path} does not exist. Cannot delete.")
 
     def pop_jsonpath(self, json_path, default=NO_ARGUMENT, ensure_exists=False) \
         -> Union[dict, list, int, str, float]:
@@ -364,17 +371,24 @@ class JsonResource(Resource):
         self.delete_jsonpath(json_path, ensure_exists=ensure_exists)
         return data
 
-    def set_jsonpath(self, json_path:str, insert_value:any, must_exist:bool=False):
+    def set_jsonpath(self, json_path:str, insert_value:any, must_exist:bool=False, overwrite:bool=True):
         """
         Sets value at jsonpath location.
 
         Can create a new key if it doesn't exist.
         """
 
+        path_exists = self.jsonpath_exists(json_path)
+
         # If the path must exist, and is missing, we can
         # raise an error by getting the path
-        if must_exist:
-            self.get_jsonpath(json_path)
+        if not path_exists and must_exist:
+            raise AssetNotFoundError(f"Path {json_path} does not exist. Cannot set value.")
+
+        # If overwrite is false, it will set the path only
+        # if there is no path.
+        if path_exists and not overwrite:
+            return
 
         # Otherwise, set the value
         dpath.util.new(self.data, json_path, insert_value)
@@ -1038,11 +1052,11 @@ class BehaviorPack(Pack):
         return self.__entities
 
     @cached_property
-    def animation_controller_files(self) -> list[AnimationControllerFile]:
+    def animation_controller_files(self) -> list[AnimationControllerFileRP]:
         base_directory = os.path.join(self.input_path, "animation_controllers")
         for local_path in glob.glob(base_directory + "/**/*.json", recursive=True):
             local_path = os.path.relpath(local_path, self.input_path)
-            self.__animation_controller_files.append(AnimationControllerFile(file_path = local_path, pack = self))
+            self.__animation_controller_files.append(AnimationControllerFileRP(file_path = local_path, pack = self))
             
         return self.__animation_controller_files
 
